Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Console_ServiceDesc = grpc.ServiceDesc{ ServiceName: "api.console.Console", HandlerType: (*ConsoleServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{}, Metadata: "console/console.proto", }
Console_ServiceDesc is the grpc.ServiceDesc for Console service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_console_console_proto protoreflect.FileDescriptor
Functions ¶
func RegisterConsoleServer ¶
func RegisterConsoleServer(s grpc.ServiceRegistrar, srv ConsoleServer)
Types ¶
type ConsoleClient ¶
type ConsoleClient interface {
}
ConsoleClient is the client API for Console service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewConsoleClient ¶
func NewConsoleClient(cc grpc.ClientConnInterface) ConsoleClient
type ConsoleServer ¶
type ConsoleServer interface {
// contains filtered or unexported methods
}
ConsoleServer is the server API for Console service. All implementations must embed UnimplementedConsoleServer for forward compatibility.
type UnimplementedConsoleServer ¶
type UnimplementedConsoleServer struct{}
UnimplementedConsoleServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
type UnsafeConsoleServer ¶
type UnsafeConsoleServer interface {
// contains filtered or unexported methods
}
UnsafeConsoleServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConsoleServer will result in compilation errors.